@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use XML::DT;
 $loaded = 1;
@@ -18,3 +18,12 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+# Test pathdtstring and | operator
+if("212" eq pathdtstring("<a><b>1</b><c>1</c><d>1</d></a>",
+				('-default' => sub{"$c"},
+				 'b|d' => sub{"2"}))) {
+	print "ok 2\n";
+} else {
+	print "not ok 2\n";
+}
+				
